import { LitElement } from 'lit';
/**
 *  A box for grouping elements
 *  @element uui-box
 *  @slot headline - headline area, this area is placed within the headline tag which is located inside the header. Use this to ensure the right headline styling.
 *  @slot header - header area, use this for things that is not the headline but located in the header.
 *  @slot default - area for the content of the box
 *  @cssprop --uui-box-default-padding - overwrite the box padding
 *
 */
export declare class UUIBoxElement extends LitElement {
    static styles: import("lit").CSSResult[];
    /**
     * Headline for this box, can also be set via the 'box' slot.
     * @type string
     * @attr
     * @default null
     */
    headline: string | null;
    private _headlineSlotHasContent;
    private _headlineSlotChanged;
    private _headerSlotHasContent;
    private _headerSlotChanged;
    /**
     * Renders a header with the header-slot, headline and headline-slot within
     * @returns {TemplateResult}
     * @protected
     * @method
     */
    protected renderHeader(): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-box': UUIBoxElement;
    }
}
